summaryrefslogtreecommitdiffstats
path: root/challenge/c08.go
diff options
context:
space:
mode:
authorrsiddharth <s@ricketyspace.net>2020-12-06 16:44:19 -0500
committerrsiddharth <s@ricketyspace.net>2020-12-06 16:44:19 -0500
commit3e18e852ca696742dba09cfa6862c801fca5fa65 (patch)
tree6d94929bc81d1f1d0ec5c2b325226be0e8ca0650 /challenge/c08.go
parent6a820a2e307c971315ee153e4154d52fdd0ba2cd (diff)
challenge: fix challenge 08
Diffstat (limited to 'challenge/c08.go')
-rw-r--r--challenge/c08.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/challenge/c08.go b/challenge/c08.go
index e965080..8952a41 100644
--- a/challenge/c08.go
+++ b/challenge/c08.go
@@ -10,14 +10,14 @@ import (
func C8() {
for i := 0; i < len(c08); i++ {
- bs := lib.StrToBytes(c08[i])
+ bs := lib.HexStrToBytes(c08[i])
block := isECB(bs)
if block != nil {
fmt.Printf("Cipher at line %d (%s)", i+1, c08[i])
fmt.Printf(" might be AES encrypted in ECB mode.\n")
- fmt.Printf("16-byte block '%s'", block)
- fmt.Printf(" occurs twice in this cipher.\n")
+ fmt.Printf("16-byte block '%s'", lib.BytesToHexStr(block))
+ fmt.Printf(" occurs more than once this cipher.\n")
}
}
}
@@ -25,7 +25,7 @@ func C8() {
// Output:
//
// Cipher at line 133 (d880619740a8a19b7840a8a31c810a3d08649af70dc06f4fd5d2d69c744cd283e2dd052f6b641dbf9d11b0348542bb5708649af70dc06f4fd5d2d69c744cd2839475c9dfdbc1d46597949d9c7e82bf5a08649af70dc06f4fd5d2d69c744cd28397a93eab8d6aecd566489154789a6b0308649af70dc06f4fd5d2d69c744cd283d403180c98c8f6db1f2a3f9c4040deb0ab51b29933f2c123c58386b06fba186a) might be AES encrypted in ECB mode.
// 16-byte block '08649af70dc06f4f' occurs twice in this cipher.
func isECB(bs []byte) []byte {
blocks := lib.BreakIntoBlocks(bs, 16)
@@ -25,7 +25,7 @@ func C8() {
//
// Cipher at line 133 (d880619740a8a19b7840a8a31c810a3d08649af70dc06f4fd5d2d69c744cd283e2dd052f6b641dbf9d11b0348542bb5708649af70dc06f4fd5d2d69c744cd2839475c9dfdbc1d46597949d9c7e82bf5a08649af70dc06f4fd5d2d69c744cd28397a93eab8d6aecd566489154789a6b0308649af70dc06f4fd5d2d69c744cd283d403180c98c8f6db1f2a3f9c4040deb0ab51b29933f2c123c58386b06fba186a) might be AES encrypted in ECB mode.
-// 16-byte block '08649af70dc06f4f' occurs twice in this cipher.
+// 16-byte block '08649af70dc06f4fd5d2d69c744cd283' occurs more than once this cipher.
func isECB(bs []byte) []byte {
blocks := lib.BreakIntoBlocks(bs, 16)